# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2011 Juanjo Abenza. All Rights Reserved
#    d$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
from time import strftime


class imports_moodle_subscriptions(osv.osv):

	# Intermediate object used to complete the mapping subscriptions received from Moodle.


	_name = 'imports.moodle.subscriptions'

	_columns = {
		'connection':fields.many2one('training.moodle.connection', 'Connection',
                                     readonly=True, select=True),
		'subscription_id' : fields.many2one('training.subscription',
                                            'Subscription', select=True),
		'session_id' : fields.many2one('training.session', 'Session',
            select=True,
            help='You can create Subscrition Lines with differents Sessions'),
		'participant_id' : fields.many2one('res.partner.job',
                                'Participation', readonly=True, select=True),
		'price_id' : fields.many2one('product.pricelist', 'Price List',
                                     select=True),
		'off_subscrip' : fields.many2one('training.offer', 'Offer', select=True,
                                         readonly=True),
		#'mapping_created': fields.many2one('link.connection.subscription',
		#                                         'Created mapping'),
		'course_type_id' : fields.float('Sales Price', size=64, required=False),
		'mapping_created': fields.one2many('link.connection.subscription',
                            'moodle_import_subs', 'Created Mappings', select=True),
	}

	def name_get(self, cr, uid, ids, context):
		if not ids:
			return []
		res = []
		for r in self.read(cr, uid, ids, ['connection', 'participant_id'], context):
			res.append((r['id'], '%s-%s' % (r['connection'], 'participant_id')))
		return res

	def import_subscriptions(self, cr, uid, ids, context=None):
		if context is None:
			context = {}

		moodle_subs_obj = self.browse(cr, uid, ids[0], context)
		print moodle_subs_obj.id
		dat = strftime('[%Y-%m-%d] ')
		job_id = moodle_subs_obj.participant_id and \
                                moodle_subs_obj.participant_id.id or False
		email_part = moodle_subs_obj.participant_id and \
                                moodle_subs_obj.participant_id.email or False
		session_id = moodle_subs_obj.session_id and \
                                moodle_subs_obj.session_id.id or False
		price_list_id = moodle_subs_obj.price_id and \
                                moodle_subs_obj.price_id.id or False
		price = moodle_subs_obj.course_type_id
		subscription_id = moodle_subs_obj.subscription_id and \
                                moodle_subs_obj.subscription_id.id or False
		off_id = moodle_subs_obj.off_subscrip and \
                                moodle_subs_obj.off_subscrip.id or False
		connection = moodle_subs_obj.connection and \
                                moodle_subs_obj.connection.id or False

        # Create subscription line
		request = self.pool.get('training.subscription.line')
		values = {
                  'job_id' : job_id,
                  'session_id': session_id,
                  'price_list_id': price_list_id,
                  'price': price,
                  'subscription_id': subscription_id,
                  'job_email': email_part,
                  }
		subscription_line_id = request.create(cr, uid, values, context)
		
        # Create a link connection subscription.
		request2 = self.pool.get('link.connection.subscription')
		values = {
                  'connection' : connection,
                  'id_subscription_a': subscription_id,
                  'id_participant': job_id,
                  'id_subscription_line_a': subscription_line_id,
                  'session_id': session_id,
                  'off_subscrip_o': off_id,
                  'data': dat,
                  'moodle_import_subs': moodle_subs_obj.id,
                  }
		request2.create(cr, uid, values)

	

imports_moodle_subscriptions()
