# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2011 Juanjo Abenza. All Rights Reserved
#    d$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
from time import strftime

# Objecte intermedi on es guarden i s'especifiquen les dades dels cursos i materies rebudes de Moodle, creant-se a OpenERP.

class link_connection_course(osv.osv):
    # Unused class. You must define it first in the __init__.py file
    # to allow relationships
    _name = 'link.connection.course'
link_connection_course()

class training_moodle_course(osv.osv):
    _name = 'training.moodle.course'

    _columns = {
        'name':fields.char('Long Name', size=64, required=False, readonly=True),
        'short_name':fields.char('Short Name', size=64, required=False, readonly=True),
        'moodleid': fields.integer('Moodle ID', size=64, required=False, readonly=True),
        'weeks': fields.float('Duration', required=False, readonly=True),
        'state': fields.selection([('course','Course'),('offer','Offer'),('course_offer','1 Course 1 offer')],'Role',help='Select a type for the import object'),
        'id_connection': fields.many2one('training.moodle.connection', 'Connection', select=True, readonly=True),
        'mapping_created': fields.many2one('link.connection.course', 'Created mapping', readonly=True),
        'lang_id' : fields.many2one('res.lang', 'Language', select=True),
        'product_id' : fields.many2one('product.product', 'Product', select=True),
        'format_id' : fields.many2one('training.offer.format', 'Format', select=True),
        'product_line_id' : fields.many2one('training.course_category', 'Product Line', select=True),
        'course_type_id' : fields.many2one('training.course_type', 'Type', select=True),
        'splitted_by' : fields.float('Splitted By', required=False),
        'data': fields.date('Record date', readonly=True),
    }

    def import_moodle_course(self, cr, uid, ids, context=None):    

        if context is None:
            context = {}

        training_course_obj = self.pool.get('training.course')
        lc_course_obj = self.pool.get('link.connection.course')
        training_offer_obj = self.pool.get('training.offer')
        t_course_offer_rel_obj = self.pool.get('training.course.offer.rel')

        # Variable definitions
        t_moodle_course = self.browse(cr, uid, ids[0], context)
        name = t_moodle_course.short_name
        long_name = t_moodle_course.name
        lang_id = t_moodle_course.lang_id.id
        product_id = t_moodle_course.product_id.id
        product_line_id = t_moodle_course.product_line_id.id
        format_id = t_moodle_course.format_id.id
        course_type_id = t_moodle_course.course_type_id.id
        connection_id = t_moodle_course.id_connection.id
        state = t_moodle_course.state
        splitted_by = t_moodle_course.splitted_by
        duration = t_moodle_course.weeks
        moodle_id = t_moodle_course.moodleid
        mapping_created = t_moodle_course.mapping_created # Unused variable
        date = strftime('[%Y-%m-%d] ')

        # Create offer
        if state == "offer":
            offer_id = training_offer_obj.create(cr, uid, {
                                       'name' : name,
                                       'kind': 'standard',
                                       'lang_id': lang_id,
                                       'product_line_id': product_line_id,
                                       'format_id': format_id,
                                       'product_id': product_id
            })
            print offer_id
            # offer = training_offer_obj.browse(cr, uid, offer_id, context) # Unnecessary browse
            # LINK CONNECTION COURSE. Es guarda un registre amb una materia.
            mapping_created =lc_course_obj.create(cr, uid, {
                                        'connection' : connection_id, 
                                        'offer_id': offer_id, 
                                        'id_moodle': moodle_id, 
                                        'data': date
            })
            print "mapping_created"
            print mapping_created
            self.write(cr, uid, ids, {'mapping_created': mapping_created})
        # Create course
        elif state == "course":
            
            course_id = training_course_obj.create(cr, uid, {
                            'name' : name,
                            'kind': 'standard',
                            'long_name': long_name,
                            'lang_id': lang_id,
                            'category_id': product_line_id,
                            'course_type_id': course_type_id,
                            'duration': duration
            })

            # LINK CONNECTION COURSE. Es guarda un registre amb un curs.
            mapping_created = lc_course_obj.create(cr, uid, {
                                         'connection' : connection_id,
                                         'course_id': course_id,
                                         'id_moodle': moodle_id,
                                         'data': date
            })
            self.write(cr, uid, ids, {'mapping_created':mapping_created})
        # Create offer with unique course
        elif state == "course_offer":
            # Es crea el curs i s'obte l'id d'aquest
            offer_id = training_offer_obj.create(cr, uid, {
                            'name' : name,
                            'kind': 'standard',
                            'lang_id': lang_id,
                            'product_line_id': product_line_id,
                            'format_id': format_id,
                            'product_id': product_id
            })
            # Es crea la materia i s'afegeix al curs anteriorment creat. S'afegeix per mitja de l'objecte 'training.course.offer.rel', que es la relacio entre
            # el curs i la materia.
            course_id = training_course_obj.create(cr, uid, {
                            'name' : name,
                            'kind': 'standard',
                            'long_name': long_name,
                            'lang_id': lang_id,
                            'category_id': product_line_id,
                            'course_type_id': course_type_id,
                            'splitted_by': splitted_by,
                            'duration': duration
            })
            course_offer_rel_id = t_course_offer_rel_obj.create(cr, uid, {
                            'course_id': course_id,
                            'offer_id': offer_id
            })
            # LINK CONNECTION COURSE. Es guarda un registre amb un curs i una materia.
            mapping_created = lc_course_obj.create(cr, uid, {
                            'connection' : connection_id,
                            'course_id': course_id,
                            'offer_id': offer_id,
                            'id_moodle': moodle_id,
                            'data': date
            })
            # Save mapped object to field to see your information and to disable the button of the view.
            self.write(cr, uid, ids, {'mapping_created':mapping_created})
            ## Make it with workflow
            # request_c_3.write(cr, uid, course_ides, {'state_course': 'validated'})

training_moodle_course()
