# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2011 Juanjo Abenza. All Rights Reserved
#    d$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
from xml.dom.minidom import parseString
from time import strftime
from conection import mdl_connection
import netsvc

# Wizard encarregat de crear els cursos i materies exitents d'OpenERP com a cursos a Moodle

class export_courses_wizard(osv.osv_memory):
    _name = 'export.courses.wizard'
    _columns = {
        'participation_id' : fields.many2one('training.moodle.connection', 'Connection', required=True, select=True),
    }

    def close_cb(self, cr, uid, ids, context=None):
        return {'type' : 'ir.actions.act_window_close'}

    def apply_cb(self, cr, uid, ids, context):

        if not context:
            context = {}
        mdl = mdl_connection()

        timestamp = strftime('[%Y-%m-%d %H:%M:%S] ')
        #Agafa el valor del registre connection sel.leccionat al wizard
        ids = self.search(cr,uid,[])
        conx = self.browse(cr, uid, ids, context)
        url = conx[0].participation_id.url
        token = conx[0].participation_id.token
        user_id = 0 # store moodleid returned in response
        # nomes recupera els id's dels objectes. 
        offer_ids = self.pool.get('training.offer').search(cr, uid, [('state','!=', "draft")])
        # recupera tots els camps dels id's idexists
        offers = self.pool.get('training.offer').browse(cr, uid, offer_ids, context)
        
        for offer in offers:
            offer_name = offer.name
            # Recupera el id del contacte actual
            offer_id = offer.id
            # Recupera el id de la conexio
            connection = self.browse(cr, uid, ids[0], context) #recupero nombre actual
            connection_id = connection.id
            # Com el curs a OERP nomes te un nom i moodle demana dos, es posa el mateix a tots dos    
            function = 'moodle_course_create_courses&courses[0][fullname]=' + offer_name + '&courses[0][shortname]=' + offer_name + '&courses[0][categoryid]=1'
            response = mdl.conn_rest(url, token, function)
            if response.find('VALUE')>-1: # si en "response" se encuentra VALUE entra en el if
                dom = parseString(response)
                i = 0
                for node in dom.getElementsByTagName('VALUE'):
                    i = i + 1
                    # get first value (user ID)
                    if i==1:
                        valueResponse = node.toxml()
                        user_id = valueResponse.replace('<VALUE>','').replace('</VALUE>','')
                    # get second value (username)
                    elif i==2:
                        valueResponse = node.toxml()
                        username = valueResponse.replace('<VALUE>','').replace('</VALUE>','')
                last = timestamp + 'New Moodle course (' + username + ') created sucessfully with ID: ' + user_id + '.'
                print last
                # LINK CONNECTION Guardo informació de la conexió als registres creats de link.connection.contact
                # LINK CONNECTION OFFER
                link_connec_course_obj = self.pool.get('link.connection.course')
                link_connec_course_obj.create(cr, uid, {'connection' : connection_id, 'offer_id': offer_id, 'id_moodle': user_id, 'data': timestamp})
            # si response conte "invalid_parameter_exception" vol dir que l'usuari de Moodle ja existeix
            elif response.find('invalid_parameter_exception')>-1: # user exists error
                #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_ERROR, "Error: user already exists in Moodle!")
                last = 'Course already exists in Moodle'
                print last 
            else: # an error has occured
                #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "Unknown error. Moodle server says: %S" % response)
                last = 'Course already exists in Moodle.'
                print last
            courses = offer.course_ids
            for course in courses:
                course_id = course.id
                course_offer_rel = self.pool.get('training.course.offer.rel').browse(cr, uid, course_id, context)
                course_id = course_offer_rel.course_id.id
                course_name = course_offer_rel.course_id.name
                course_long_name = course_offer_rel.course_id.long_name
                if course_long_name == False:
                    function = 'moodle_course_create_courses&courses[0][fullname]=' + course_name + '&courses[0][shortname]=' + course_name + '&courses[0][categoryid]=1'
                else:
                    function = 'moodle_course_create_courses&courses[0][fullname]=' + course_long_name + '&courses[0][shortname]=' + course_name + '&courses[0][categoryid]=1'
                response = mdl.conn_rest(url, token, function)
                if response.find('VALUE')>-1: # si en "response" es troba VALUE entra al if
                    dom = parseString(response)
                    i = 0
                    for node in dom.getElementsByTagName('VALUE'):
                        i = i + 1
                        # get first value (user ID)
                        if i==1:
                            valueResponse = node.toxml()
                            courseIDe = valueResponse.replace('<VALUE>','').replace('</VALUE>','')
                        # get second value (username)
                        elif i==2:
                            valueResponse = node.toxml()
                            username = valueResponse.replace('<VALUE>','').replace('</VALUE>','')
                    last = timestamp + 'New Moodle course (' + course_name + ') created sucessfully with ID: ' + courseIDe + '.'
                    # LINK CONNECTION Guardo informació de la conexió als registres creats de link.connection.contact
                    # LINK CONNECTION COURSE
                    link_connec_course_obj.create(cr, uid, {
                                                'connection' : connection_id,
                                                'course_id': course_id,
                                                'id_moodle': courseIDe,
                                                'data': timestamp
                    })
                # si response conte "invalid_parameter_exception" vol dir que l'usuari de Moodle ja existeix
                elif response.find('invalid_parameter_exception')>-1: # user exists error
                    #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "Error: user already exists in Moodle")
                    last = 'Course already exists in Moodle'
                    print last 
                else: # an error has occured
                    #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "Unknown error. Moodle server says: %s" % response)
                    last = 'Course already exists in Moodle.'
                    print last
        #return 0
        return {'type' : 'ir.actions.act_window_close'}

export_courses_wizard()
