# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2011 Juanjo Abenza. All Rights Reserved
#    d$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
from conection import mdl_connection

class export_subscriptions_wizard(osv.osv_memory):
    '''
        This Wizard creates OpenERP subscriptions in Moodle
    '''
    _name = 'export.subscriptions.wizard'

    _columns = {
        'participation_id' : fields.many2one('training.moodle.connection', 'Connection', required=True, select=True),
    }

    def close_cb(self, cr, uid, ids, context=None):
        return {'type' : 'ir.actions.act_window_close'}

    def apply_cb(self, cr, uid, ids, context=None):
        mdl = mdl_connection()
        if context is None:
            context = {}

        #Agafa el valor del registre connection sel.leccionat al wizard
        subscription_line_obj = self.pool.get('training.subscription.line')
        link_connec_contact_obj = self.pool.get('link.connection.contact')
        link_connec_course_obj = self.pool.get('link.connection.course')
        course_offer_rel_obj = self.pool.get('training.course.offer.rel')

        offer_obj = self.pool.get('training.offer')
        export_subscriptions_wizard = self.browse(cr, uid, ids, context)
        url = export_subscriptions_wizard[0].participation_id.url
        token = export_subscriptions_wizard[0].participation_id.token
        connection_id = export_subscriptions_wizard[0].participation_id.id
        # Agafa valors de curs(offer) i contact de linia de inscripcio.
        # La inscripcio ha d'estar validada (state)
        subscription_line_ids = subscription_line_obj.search(cr, uid, [('state','!=', "draft")])
        subscription_lines = subscription_line_obj.browse(cr, uid, subscription_line_ids, context)

        for subscription_line in subscription_lines:
            offer_id = subscription_line.offer_id.id
            contact_id = subscription_line.contact_id.id
            # Exporta les linies d'incripcio a Moodle (Course i Contact existents)
            # Tenim en compte que el curs i l'user existeixen a moodle
            # Treiem per aquella conexio quin es l'id a moodle del contacte de la inscripcio a crear a moodle
            link_connec_contact_ids = link_connec_contact_obj.search(cr, uid, [
                                          ('contact_id','=', contact_id),
                                          ('connection','=', connection_id)
                                          ])
            link_connec_contacts = link_connec_contact_obj.browse(cr, uid, 
                                            link_connec_contact_ids, context)
            user_id = link_connec_contacts[0].id_moodle
            # Treiem per aquella conexio quin es l'id a moodle del curs/materia de la inscripcio a crear a moodle. Fer un OR per offer_id/course_id
            link_connec_course_ids = link_connec_course_obj.search(cr, uid, [
                                            ('offer_id','=', offer_id),
                                            ('connection','=', connection_id)
                                            ])
            link_connec_courses = link_connec_course_obj.browse(cr, uid, link_connec_course_ids, context)
            course_id = link_connec_courses[0].id_moodle
            # roleid : 1 --> Gestor
            # roleid : 2 --> Creador de curso
            # roleid : 3 --> Profesor
            # roleid : 4 --> Profesor sin permiso de edición
            # roleid : 5 --> Estudiante
            # roleid : 6 --> Invitado
            # roleid : 7 --> Usuario identificado
            # roleid : 8 --> Usuario identificado en la página principal                    

            # Para no entorpecer la automatizacion de las matriculaciones simpre asignamos al moodle user el rol de estudiante
            enrols =[{
                'roleid': 5,
                'userid': user_id,
                'courseid': course_id,
                }]
            response = mdl.enrol_users(url, token, enrols)

            offer = offer_obj.browse(cr, uid, offer_id, context)
            # id's del les materies d'aquell curs
            courses = offer.course_ids
            for course in courses:
                course_id = course.id
                # relacio curs/materies
                course_offer_rel = course_offer_rel_obj.browse(cr, uid, 
                                                          course_id, context)
                #id de la materia del curs especificat
                course_id = course_offer_rel.course_id.id
                # Treiem per aquella conexio quin es l'id a moodle del curs/materia de la inscripcio a crear a moodle. Fer un OR per offer_id/course_id
                link_connec_course_ids = link_connec_course_obj.search(cr, uid, [
                                            ('course_id','=', course_id),
                                            ('connection','=', connection_id)
                                            ])
                link_connec_courses = link_connec_course_obj.browse(cr, uid, link_connec_course_ids, context)
                course_id = link_connec_courses[0].id_moodle

                enrols =[{
                    'roleid': 5,
                    'userid': user_id,
                    'courseid': course_id,
                }]
                response = mdl.enrol_users(url, token, enrols)

        # return 0
        return {'type' : 'ir.actions.act_window_close'}

export_subscriptions_wizard()
