# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2011 Juanjo Abenza. All Rights Reserved
#    d$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
import netsvc

from xml.dom.minidom import parseString
from conection import mdl_connection

class training_synchronize_subscriptions_wizard(osv.osv_memory):
    '''
        This wizard makes petitions to Moodle for subscriptions.
        Users and Moodle courses must be imported before subscriptions in OpenERP
    '''

    _name = 'training.synchronize.subscriptions.wizard'
    _columns = {
        'participation_id' : fields.many2one('training.moodle.connection', 'Connection', required=True, select=True),
    }

    def close_cb(self, cr, uid, ids, context=None):
        return {'type' : 'ir.actions.act_window_close'}

    def apply_cb(self, cr, uid, ids, context=None):
        if context is None:
            context = {}
        mdl = mdl_connection()
        lc_course_obj = self.pool.get('link.connection.course')
        lc_contact_obj = self.pool.get('link.connection.contact')
        import_moodle_subs_obj = self.pool.get('imports.moodle.subscriptions')
        training_session_obj = self.pool.get('training.session')
        # Get the selected connection registry value from wizard
        ids = self.search(cr, uid, [])
        conx = self.browse(cr, uid, ids, context)
        url = conx[0].participation_id.url
        token = conx[0].participation_id.token
        idconnection = conx[0].participation_id.id
        # Restore the contacts imported from moodle. As it is assumed that 
        # users are already in Moodle, we can search in imported users from OERP.
        ids_m = lc_contact_obj.search(cr, uid, [])
        # Retrieves all indexed fields
        contacts_link = lc_contact_obj.browse(cr, uid, ids_m, context)
        # For each course there may be several subscripted users. For each course you have to see what users. Extract information.
        for cont_link in contacts_link:
            #id moodle del contacte analitzat
            idcont = cont_link.id_moodle
            # Give the selected connection registry value from  wizard
            ids = self.search(cr, uid, [])
            conx = self.browse(cr, uid, ids, context)
            url = conx[0].participation_id.url
            token = conx[0].participation_id.token
            id_conx = conx[0].participation_id.id
            # Get the courses they are enrolled idcont web services
            function = 'moodle_enrol_get_users_courses&userid=' + str(idcont)
            response = mdl.conn_rest(url, token, function)
            # If there is a course analyzes the xml response to extract information from users
            if response.find('KEY') > -1:
                dom = parseString(response)
                for cont_inf in dom.getElementsByTagName('KEY'):
                    a = cont_inf.attributes["name"]
                    nombreES = a.value
                    if nombreES == "id":
                        if nombreES != "":
                            try:
                                valueResponse = cont_inf.toxml()
                                xmlData3 = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData3 = xmlData3.replace('<KEY name="id">', '').replace('</KEY>', '')
                                lc_contact_ids = lc_contact_obj.search(cr, uid, [('id_moodle', '=', idcont), ('connection', '=', id_conx)])
                                lc_contact = lc_contact_obj.browse(cr, uid, lc_contact_ids, context)
                                contact_id = lc_contact[0].contact_id.id
                                email = lc_contact[0].contact_id.email
                                # Create participant with contact id.
                                part_id = self.pool.get('res.partner.job')
                                part_eq = part_id.search(cr, uid, [('contact_id', '=', contact_id), ('email', '=', email)])
                                if part_eq == []:
                                    idpart = part_id.create(cr, uid, {'contact_id':contact_id, 'email': email})

                                else:
                                    idpart = part_eq[0]

                                # Only gets registries of 'link.connection.course' that are offers. Only courses no.
                                lc_course_ids = lc_course_obj.search(cr, uid, [('id_moodle', '=', xmlData3), ('connection', '=', id_conx), ('offer_id', '!=', None)])
                                # If there is any record is that there are courses.
                                if lc_course_ids != []:
                                    lc_course = lc_course_obj.browse(cr, uid, lc_course_ids[0], context)
                                    offer_id = lc_course.offer_id.id

                                    # Finds the id of the session which was previously created and that have the offer id
                                    session_id = training_session_obj.search(cr, uid, [('offer_id', '=', offer_id)])
                                    if session_id != []:
                                        # Mirem si aquest usuari ja existeix a OERP com un contacte de Moodle. S'aconsegueix mirant l'id de la connexio, l'id del curs, i l'id del participant.
                                        import_moodle_subs_ids = import_moodle_subs_obj.search(cr, uid, [('connection', '=', idconnection), ('off_subscrip', '=', offer_id), ('participant_id', '=', idpart)])
                                        # Mira que no existeixi ja un id am la conexio, sessio i participant iguals
                                        if import_moodle_subs_ids == []:
                                            # es guarda idcont(id participant) a moodle subscription mappings
                                            import_moodle_subs_obj.create(cr, uid, {'connection': idconnection, 'participant_id':idpart, 'off_subscrip': offer_id, 'price_id': 1})
                                        else:
                                            netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "There is already in OpenERP!")

                            except NameError:
                                netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_ERROR, 'Unknown error. Moodle server says:id')
                        else:
                            netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "No number id")
        return {'type' : 'ir.actions.act_window_close'}

training_synchronize_subscriptions_wizard()
