# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution    
#    Copyright (C) 2011 Juanjo Abenza. All Rights Reserved
#    d$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
from conection import mdl_connection
from time import strftime
import netsvc

class import_users_wizard(osv.osv_memory):
    ''' Wizard responsible of making petitions necessary to get Moodle users 
        and their respective information.
        Only will be get users enrolled in an offer.
        First there must be offer in OpenERP.
        All students will be saved as contacts.'''

    _name = 'import.users.wizard'
    _columns = {
        'participation_id' : fields.many2one('training.moodle.connection', 'Connection', required=True, select=True),
    }

    def close_cb(self, cr, uid, ids, context=None):
        return {'type' : 'ir.actions.act_window_close'}

    def apply_cb(self, cr, uid, ids, context):
        mdl = mdl_connection()
        if not context:
            context = {}
        timestamp = strftime('[%Y-%m-%d] ')
        # Get the selected connection registry value to wizard and the connection information
        
        ids = self.search(cr, uid, [])
        import_users_wizard = self.browse(cr, uid, ids, context)
        url = import_users_wizard[0].participation_id.url
        token = import_users_wizard[0].participation_id.token
        import_users_wizard_id = import_users_wizard[0].id
        
        # Retrieve imported offers from Moodle
        contact_obj = self.pool.get('res.partner.contact')
        link_connec_contact_obj = self.pool.get('link.connection.contact')
        link_connection_course_obj = self.pool.get('link.connection.course')

        link_connection_course_ids = link_connection_course_obj.search(cr, uid, [])
        # Retrieves all fields of id's
        link_connection_courses = link_connection_course_obj.browse(cr, uid, link_connection_course_ids, context)
        # For each course there can be multiple registered users. For each course you have to see what users have. Extract information.
        for link_connection_course in link_connection_courses:
            # id moodle del curs analitzat
            # moodle's id of the analyzed course
            moodle_id = link_connection_course.id_moodle
            mdl = mdl_connection()
            # Request to Moodle webservice
            function = 'moodle_user_get_users_by_courseid&courseid=' + str(moodle_id) + '&options[0][name]=string&options[0][value]=string'
            # From here we analyze the Moodle server response to broken down it and to get the necessary information.
            response = mdl.conn_rest_NOVIEMBRE(url, token, function)
            # Retrieves the id of the connection
            #import_users_wizard_id = import_users_wizard.id
            nodos = response.childNodes
            lista = nodos[0].getElementsByTagName("SINGLE")
            for course_inf in lista:
                bitref = course_inf.childNodes[3]
                a = bitref.attributes["name"]
                NAMEoo = a.value
                if NAMEoo == "fullname":
                    #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "Skip %s" % NAMEoo)
#                    print "continue"
                    continue
                else:
                    lista2 = course_inf.getElementsByTagName("KEY")
                    for course_inf_ in lista2:
                        ab = course_inf_.attributes["name"]
                        # The name tags of the xml response
                        nombreES = ab.value
                        if nombreES == "enrolledcourses":
                            #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_WARNING, "nombreES == 'enrolledcourses'")
#                            print "break"
                            break
                        elif nombreES == "id":
                            try:
                                valueResponse = course_inf_.toxml()
                                xmlData3 = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData3guardado = xmlData3.replace('<KEY name="id">', '').replace('</KEY>', '')
                                # If there is any contact in link.connection.contact with the ID received from moodle, skip it, otherwise, create it.
                                id_moodle_link = link_connec_contact_obj.search(cr, uid, [('id_moodle', '=', xmlData3guardado)])
                                if id_moodle_link == []:
                                    continue
                                else:
                                    break
                            except NameError:
                                #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_ERROR, 'Unknown error. Moodle server says:id')
                                # An error has occurred
                                last = 'Unknown error. Moodle server says: id'#+ response
                                print last
                        elif nombreES == "firstname":
                            try:
                                valueResponse = course_inf_.toxml()
                                xmlData = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData = xmlData.replace('<KEY name="firstname">', '').replace('</KEY>', '').strip("\n")
                            except NameError:
                                #netsvc.Logger().notifyChannel('training_moodle', netsvc.LOG_ERROR, 'Unknown error. Moodle server says: fullname')
                                last = 'Unknown error. Moodle server says: firstname' #+ response
                                print last
                        elif nombreES == "lastname":
                            # If the user already exists in OpenERP as a Moodle contact skip it
                            if id_moodle_link == []:
                                try:
                                    valueResponse = course_inf_.toxml()
                                    xmlData2 = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                    xmlData2 = xmlData2.replace('<KEY name="lastname">', '').replace('</KEY>', '').strip("\n")
                                    idreg = contact_obj.create(cr, uid, {
                                                        'name':xmlData2,
                                                        'first_name':xmlData
                                                        })                
                                    link_connec_contact_obj.create(cr, uid, {
                                        'connection' : import_users_wizard_id,
                                        'contact_id': idreg,
                                        'id_moodle': xmlData3guardado,
                                        'data': timestamp
                                        })
                                    print "New OpenERP Contact created sucessfully"
                                except NameError:
                                # an error has occurred
                                    #netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_ERROR, "Unknown error.")
                                    last = 'Unknown error. Moodle server says: lastname'#+ response
                                    print last    
#                                else:
#                                    netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_WARNING, "No number id!")
                                    #print "no number id"
                            else:
                                #netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_WARNING, "The user already exists in OpenERP!")
                                print "User already exists as a Moodle OpenERP contact"
                        elif nombreES == "email":
#                            if nombreES != "": # if nombreEs == "lastname" is obvious nombreES != ""
                            try:
                                valueResponse = course_inf_.toxml()
                                xmlData = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData = xmlData.replace('<KEY name="email">', '').replace('</KEY>', '')
                                tra = contact_obj
                                tra.write(cr, uid, idreg, {'email':xmlData})
                            except NameError:
                            # An error has occurred
                                #netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_ERROR, "Unknown error.")
                                last = 'Unknown error. Moodle server says: email' #+ response
                                print last
                        elif nombreES == "phone2":
                            try:
                                valueResponse = course_inf_.toxml()
                                xmlData = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData = xmlData.replace('<KEY name="phone2">', '').replace('</KEY>', '')
                                tra = contact_obj
                                tra.write(cr, uid, idreg, {'mobile':xmlData})
                            except NameError:
                            # An error has occurred
                                #netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_ERROR, "Unknown error.")
                                last = 'Unknown error. Moodle server says: phone2' #+ response
                                print last
                        elif nombreES == "url":
                            try:
                                valueResponse = course_inf_.toxml()
                                xmlData = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData = xmlData.replace('<KEY name="url">', '').replace('</KEY>', '')
                                contact_obj.write(cr, uid, idreg, {
                                                    'website':xmlData
                                                    })
                            except NameError:
                                #netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_ERROR, "Unknown error. Moodle server says:numsections")
                            # An error has occured
                                last = 'Unknown error. Moodle server says: url' #+ response
                                print last
                        elif nombreES == "description":
#                            if nombreES != "": # if nombreEs == "description" is obvious nombreES != ""
                            try:
                                valueResponse = course_inf_.toxml()
                                xmlData = valueResponse.replace('<VALUE>', '').replace('</VALUE>', '')
                                xmlData = xmlData.replace('<KEY name="description">', '').replace('</KEY>', '')
                                xmlData = xmlData.replace('&lt;p&gt;', '').replace('&lt;/p&gt;', '')
                                tra = contact_obj
                                tra.write(cr, uid, idreg, {'comment':xmlData})
                            except NameError:
                                #netsvc.Logger().notifyChannel('import_users_wizard', netsvc.LOG_ERROR, "Unknown error. Moodle server says:numsections")
                            # An error has occured
                                last = 'Unknown error. Moodle server says:numsections' #+ response
                                print last
        return {'type' : 'ir.actions.act_window_close'}
import_users_wizard()
